==> upd-2.0-32.tgz: home/hadmin/html/users/add.php <==
<?
 /*  $id: $
This script is part of the SLIS Project initiated by the CARMI-Internet (Acadmie de Grenoble - France 38).
Ce script fait partie du projet SLIS dmarr par le CARMI-Internet (Acadmie de Grenoble - France 38).

This script have been write by Julien Dumont - copyright (C) 2001
Ce script  t crit par Julien Dumont - copyright (C) - 2001

SLIS : Serveur de communications Linux pour l'Internet Scolaire. Copyright (C) 1998-2001 Bruno Bzeznik

This program is free software; you can redistribute it and/or modify it under the terms of the GNU General Public License
as published by the Free Software Foundation; either version 2 of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied
warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License for
more details. You should have received a copy of the GNU General Public License along with this program (For example ./COPYING);
if not, write to the Free Software Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.

Please send all comments and bug reports by electronic mail to: <slis@ac-grenoble.fr>
Envoyez vos suggestions et reports de bugs par e-mail  Bruno Bzeznik <slis@ac-grenoble.fr>
*/

// tools and libs
require("../inc/pgsql.inc.php");
require("../inc/html.inc.php");
require("../inc/lib.inc.php");
require("../inc/themes.inc.php");  // themes output

// connection sql
$db = dbconnect();

//loading html part
$starthtml = startHTML("$lang_admin_users");
$end = endHTML();

//html header output
print $starthtml;

//specifique output
if($mod == "mmanu") // CREATE ACCOUNT
{
   if( (($Nom) && ($Nom != "")) && (($Prenom) && ($Prenom != "")) && (($class) && ($class != "")) )
   {
      $pass = makepass();
      $login = mklogin($Nom,$Prenom,$db);
      $query = "insert into \"users\" (nom,prenom,infos,login,passwd,modif,nouveau,delete,tovalid) VALUES ('$Nom','$Prenom','$infos','$login','$pass','0','1','0','1');";
      $v_query = pg_exec($db,$query);

      /* get user id */
      $userid = get_userid($db,$login);

      /* add encrypt passwd */
      $passmd5 = makemd5($pass);
      $passcrypt = makecrypt($pass);
      $querypass = "insert into \"password\" (id,md5,crypt) VALUES ('$userid','$passmd5','$passcrypt');";
      $v_querypass = pg_exec($db,$querypass);

      /* add user code */
      if($code)
      {
         $result = add_code($db,$code,$userid);
         if($result != "1")
         {
              $val = newsdbtbl("0",$first_tcolor,$sec_tcolor,$result,$border,"$lang_Status",$titre_color);
              $val = center($val);
              $val = saut(2)."$val";
              print "$val";
              exit;
         }
      }

      /* add user to group */
      $check = addgroup($db,$userid,$class,"1");

      /* make user first alias */
      $alias =  make_alias($Nom,$Prenom);
      $v_query = add_alias($db,$alias,$userid);

      // message de confirmation
      if($v_query)
      {
          $contenu = "<FONT FACE=\"Helvetica,Arial\">\n<CENTER><H3><I>".confirm_msg("$lang_User $Nom $Prenom --> $lang_create")."\n</I></H3><P>$lang_Valid_for_active_changes<P>\n<B><A HREF=\"./?mode=mmanu\">$lang_Back</A></B>\n</FONT>\n";
      }
      else
      {
         $contenu = errormsg("$lang_error_name_surename").center("<A HREF=\"./?mode=mmanu&Nom=$Nom&Prenom=$Prenom&code=$code&class=$class&infos=$infos\">$lang_REDO</A><br><br>");
      }
   }
   elseif( (!($class)) || $class == "")
   {
       $contenu = errormsg("$lang_error_group").center("<A HREF=\"./?mode=classe\">$lang_add_one_group</A><br><br>");
   }
   else
   {
      $contenu = errormsg("$lang_error_name_surename").center("<A HREF=\"./?mode=mmanu&Nom=$Nom&Prenom=$Prenom&code=$code&class=$class&infos=$infos\">$lang_REDO</A><br><br>");
   }
   $val = newsdbtbl("0",$first_tcolor,$sec_tcolor,$contenu,$border,"$lang_Status",$titre_color);
   $val = center($val);
   $val = saut(2)."$val";
   print "$val";
}
elseif($mod == "classe") //Creation de classe
{
  if($class)
  {
     $contenu = add_classe($class,$db);
     // changes output style in fx --> lib.inc.php
     $val = newsdbtbl("0",$first_tcolor,$sec_tcolor,$contenu,$border,"$lang_Status",$titre_color);
     $val = center($val);
     $val = saut(2)."$val";
     print "$val";
  }
  else
  {
     $contenu = errormsg("$lang_error_miss_NAME").center("<A HREF=\"./?mode=classe\">$lang_REDO</A><br><br>");
     $val = newsdbtbl("0",$first_tcolor,$sec_tcolor,$contenu,$border,"$lang_Status",$titre_color);
     $val = center($val);
     $val = saut(2)."$val";
     print "$val";
  }
}
elseif($mod == "alias") // alias creating
{
  if($alias != "")
  {
      if($aliasid == "")
      {
          $contenu = errormsg($lang_error_user).center("<A HREF=\"./?mode=mmanu\">$lang_Back</A>");
      }
      else
      {
          $check = add_alias($db,$alias,$aliasid);
          if($check == "ok")
          {
              $aliasowner = get_name($db,$aliasid);
              $contenu = "<FONT FACE=\"Helvetica,Arial\">\n<CENTER><H3><I>".confirm_msg("$lang_Alias $alias --> $aliasowner : $lang_create")."</I></H3><P>$lang_Valid_for_active_changes<P>\n<B><A HREF=\"./?mode=alias\">$lang_REDO</A></B>\n</FONT>\n";
          }
          else
          {
              $contenu = errormsg($check);
          }
      }
  }
  else
  {
      $contenu = errormsg("Il faut au moins une ent&eacute;e<BR><A HREF=\"./?mode=alias\">$lang_REDO</A>");
  }
  $val = newsdbtbl("0",$first_tcolor,$sec_tcolor,$contenu,$border,"$lang_Status",$titre_color);
  $val = center($val);
  $val = saut(2)."$val";
  print "$val";
}
elseif($mod == "multi") // AFFILIATION MULTIGROUPE
{
    $query = "select userid,classeid from \"groups\" where userid='$userid' and classeid='$classeid';";
    $checktmp = pg_exec($db,$query);
    $check = pg_numrows($checktmp);
    $check2 = get_idtype($db,$classeid);
    if( ($check == 0) && ($check2 == "classe") )
    {
        $query = "insert into \"groups\" (userid,classeid,nouveau,delete,tovalid) VALUES ('$userid','$classeid','1','0','1');";
        $v_query = pg_exec($db,$query);
    }
    else
    {
        $contenu = errormsg("<I>$lang_allready_have_Infos.\n</I></H3><P>$lang_affiliation_ignore.<P>\n<B><A HREF=\"./?mode=multi\">$lang_Back</A></B>");
        $val = newsdbtbl("0",$first_tcolor,$sec_tcolor,$contenu,$border,$lang_Status,$titre_color);
        $val = center($val);
        $val = saut(2)."$val";
        print "$val\n";
    }
    if($v_query)
    {
        $groupname = get_name($db,$classeid);
        $username = get_name($db,$userid);
        $contenu = "<BR><FONT FACE=\"Helvetica,Arial\">\n<CENTER><H3><I>".confirm_msg("$lang_Affectation $username -->  $groupname : $lang_create")."</I></H3><P>$lang_Valid_for_active_changes.<P>\n<B><A HREF=\"./?mode=multi\">$lang_Create_another_affilition</A></B>\n</FONT><BR><br>\n";
        $val = newsdbtbl("0",$first_tcolor,$sec_tcolor,$contenu,$border,$lang_Status,$titre_color);
        $val = center($val);
        $val = saut(2)."$val";
        print "$val\n";
    }
}

//close sql
pg_close($db);

?>

==> upd-2.0-36.tgz: home/hadmin/html/users/add.php <==
<?
 /*  $id: $
This script is part of the SLIS Project initiated by the CARMI-Internet (Acadmie de Grenoble - France 38).
Ce script fait partie du projet SLIS dmarr par le CARMI-Internet (Acadmie de Grenoble - France 38).

This script have been write by Julien Dumont - copyright (C) 2001
Ce script  t crit par Julien Dumont - copyright (C) - 2001

SLIS : Serveur de communications Linux pour l'Internet Scolaire. Copyright (C) 1998-2001 Bruno Bzeznik

This program is free software; you can redistribute it and/or modify it under the terms of the GNU General Public License
as published by the Free Software Foundation; either version 2 of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied
warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License for
more details. You should have received a copy of the GNU General Public License along with this program (For example ./COPYING);
if not, write to the Free Software Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.

Please send all comments and bug reports by electronic mail to: <slis@ac-grenoble.fr>
Envoyez vos suggestions et reports de bugs par e-mail  Bruno Bzeznik <slis@ac-grenoble.fr>
*/

// tools and libs
require("../inc/pgsql.inc.php");
require("../inc/html.inc.php");
require("../inc/lib.inc.php");
require("../inc/themes.inc.php");  // themes output

// connection sql
$db = dbconnect();

//loading html part
$starthtml = startHTML("$lang_admin_users");
$end = endHTML();

//html header output
print $starthtml;

//specifique output
if($mod == "mmanu") // CREATE ACCOUNT
{
   if( (($Nom) && ($Nom != "")) && (($Prenom) && ($Prenom != "")) && (($class) && ($class != "")) )
   {
      $pass = makepass();
      $login = mklogin($Nom,$Prenom,$db);
      $query = "insert into \"users\" (nom,prenom,infos,login,passwd,modif,nouveau,delete,tovalid) VALUES ('$Nom','$Prenom','$infos','$login','$pass','0','1','0','1');";
      $v_query = pg_exec($db,$query);

      /* get user id */
      $userid = get_userid($db,$login);

      /* add encrypt passwd */
      $passmd5 = makemd5($pass);
      $passcrypt = makecrypt($pass);
      $querypass = "insert into \"password\" (id,md5,crypt) VALUES ('$userid','$passmd5','$passcrypt');";
      $v_querypass = pg_exec($db,$querypass);

      /* add user code */
      if($code)
      {
         $result = add_code($db,$code,$userid);
         if($result != "1")
         {
              $val = newsdbtbl("0",$first_tcolor,$sec_tcolor,$result,$border,"$lang_Status",$titre_color);
              $val = center($val);
              $val = saut(2)."$val";
              print "$val";
              exit;
         }
      }

      /* add user to group */
      $check = addgroup($db,$userid,$class,"1");

      /* make user first alias */
      $alias =  make_alias($Nom,$Prenom);
      $v_query = add_alias($db,$alias,$userid);

      // message de confirmation
      if($v_query)
      {
          $contenu = "<FONT FACE=\"Helvetica,Arial\">\n<CENTER><H3><I>".confirm_msg("$lang_User $Nom $Prenom --> $lang_create")."\n</I></H3><P>$lang_Valid_for_active_changes<P>\n<B><A HREF=\"./?mode=mmanu\">$lang_Back</A></B>\n</FONT>\n";
      }
      else
      {
         $contenu = errormsg("$lang_error_name_surename").center("<A HREF=\"./?mode=mmanu&Nom=$Nom&Prenom=$Prenom&code=$code&class=$class&infos=$infos\">$lang_REDO</A><br><br>");
      }
   }
   elseif( (!($class)) || $class == "")
   {
       $contenu = errormsg("$lang_error_group").center("<A HREF=\"./?mode=classe\">$lang_add_one_group</A><br><br>");
   }
   else
   {
      $contenu = errormsg("$lang_error_name_surename").center("<A HREF=\"./?mode=mmanu&Nom=$Nom&Prenom=$Prenom&code=$code&class=$class&infos=$infos\">$lang_REDO</A><br><br>");
   }
   $val = newsdbtbl("0",$first_tcolor,$sec_tcolor,$contenu,$border,"$lang_Status",$titre_color);
   $val = center($val);
   $val = saut(2)."$val";
   print "$val";
}
elseif($mod == "classe") //Creation de classe
{
  if($class)
  {
     $contenu = add_classe($class,$db);
     // changes output style in fx --> lib.inc.php
     $val = newsdbtbl("0",$first_tcolor,$sec_tcolor,$contenu,$border,"$lang_Status",$titre_color);
     $val = center($val);
     $val = saut(2)."$val";
     print "$val";
  }
  else
  {
     $contenu = errormsg("$lang_error_miss_NAME").center("<A HREF=\"./?mode=classe\">$lang_REDO</A><br><br>");
     $val = newsdbtbl("0",$first_tcolor,$sec_tcolor,$contenu,$border,"$lang_Status",$titre_color);
     $val = center($val);
     $val = saut(2)."$val";
     print "$val";
  }
}
elseif($mod == "alias") // alias creating
{
  if($alias != "")
  {
      if($aliasid == "")
      {
          $contenu = errormsg($lang_error_user).center("<A HREF=\"./?mode=mmanu\">$lang_Back</A>");
      }
      else
      {
          $check = add_alias($db,$alias,$aliasid);
          if($check == "ok")
          {
              $aliasowner = get_name($db,$aliasid);
              $contenu = "<FONT FACE=\"Helvetica,Arial\">\n<CENTER><H3><I>".confirm_msg("$lang_Alias $alias --> $aliasowner : $lang_create")."</I></H3><P>$lang_Valid_for_active_changes<P>\n<B><A HREF=\"./?mode=alias\">$lang_REDO</A></B>\n</FONT>\n";
          }
          else
          {
              $contenu = errormsg($check);
          }
      }
  }
  else
  {
      $contenu = errormsg("Il faut au moins une ent&eacute;e<BR><A HREF=\"./?mode=alias\">$lang_REDO</A>");
  }
  $val = newsdbtbl("0",$first_tcolor,$sec_tcolor,$contenu,$border,"$lang_Status",$titre_color);
  $val = center($val);
  $val = saut(2)."$val";
  print "$val";
}
elseif($mod == "multi") // AFFILIATION MULTIGROUPE
{
    $query = "select userid,classeid from \"groups\" where userid='$userid' and classeid='$classeid';";
    $checktmp = pg_exec($db,$query);
    $check = pg_numrows($checktmp);
    $check2 = get_idtype($db,$classeid);
    if( ($check == 0) && ($check2 == "classe") )
    {
        $query = "insert into \"groups\" (\"userid\",\"classeid\",\"nouveau\",\"delete\",\"tovalid\",\"primary\",\"modif\") VALUES ('$userid','$classeid','1','0','1','0','0');";
        $v_query = pg_exec($db,$query);
    }
    else
    {
        $contenu = errormsg("<I>$lang_allready_have_Infos.\n</I></H3><P>$lang_affiliation_ignore.<P>\n<B><A HREF=\"./?mode=multi\">$lang_Back</A></B>");
        $val = newsdbtbl("0",$first_tcolor,$sec_tcolor,$contenu,$border,$lang_Status,$titre_color);
        $val = center($val);
        $val = saut(2)."$val";
        print "$val\n";
    }
    if($v_query)
    {
        $groupname = get_name($db,$classeid);
        $username = get_name($db,$userid);
        $contenu = "<BR><FONT FACE=\"Helvetica,Arial\">\n<CENTER><H3><I>".confirm_msg("$lang_Affectation $username -->  $groupname : $lang_create")."</I></H3><P>$lang_Valid_for_active_changes.<P>\n<B><A HREF=\"./?mode=multi\">$lang_Create_another_affilition</A></B>\n</FONT><BR><br>\n";
        $val = newsdbtbl("0",$first_tcolor,$sec_tcolor,$contenu,$border,$lang_Status,$titre_color);
        $val = center($val);
        $val = saut(2)."$val";
        print "$val\n";
    }
}

//close sql
pg_close($db);

?>
